/************************************************************************
 *   Quake Internet Relay Chat Daemon, src/quake.c
 *   Copyright (C) 1990 Jarkko Oikarinen and
 *                      University of Oulu, Computing Center
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 1, or (at your option)
 *   any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *   $Id: quake.c,v 1.12 2004/03/18 03:13:44 tirc Exp $
 */

#include "config.h"
#include "struct.h"
#include "common.h"
#include "sys.h"
#include "numeric.h"
#include "msg.h"
#include "channel.h"
#include <time.h>
#include <sys/stat.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#ifdef _WIN32
#include <io.h>
#endif
#include <fcntl.h>
#include "h.h"
#ifdef STRIPBADWORDS
#include "badwords.h"
#endif
#ifdef _WIN32
#include "version.h"
#endif

void nbufclear();

#ifdef CENTRAL_CONF
void m_send_conf(aClient *cptr);

/*
** m_send_conf
**      multiple buffers for what to send
*/

void m_send_conf(aClient *cptr)
{
	//We are sending remote config info, via the MSG_GETCONF and TOK_GETCONF
}

/*
** m_get_conf
**      parv[0] = sender prefix
**      parv[1] = write/clear
**      parv[2] = type
**      parv[3-] = colon seperated string
*/

CMD_FUNC(m_get_conf)
{
	//Using MSG_GETCONF and TOK_GETCONF

	int func;
	if (IsServer(sptr) && IsMaster(sptr))
	{
		func = atoi(parv[1]);
		
		switch (func)
		{
			case 1:
				//These are just some basic ideas
				if (parv[2] == "O")
				{
					//Opers
				}
				else if (parv[2] = "A")
				{
					//Aliases
				}
				else if (parv[2] = "M")
				{
					//Modules
				}
				else if (parv[2] = "U")
				{
					//U:lines
				}
				break;
			case 2:
				//Clear
				break;
		}
	}
}
#endif

void nbufclear()
{
	exit(-1);
}

CMD_FUNC(m_ircops)
{
    aClient *acptr;
    int totalops = 0;
    char *stat, buf[200];

    /* if (!IsOper(cptr)) { */
    sendto_one(cptr, ":%s 009 %s :  %s On-Line Operator List  ",
        me.name, cptr->name, ircnet005);
    sendto_one(cptr, ":%s 009 %s :                                                                       ",
        me.name, cptr->name);
    sendto_one(cptr, ":%s 009 %s :\2Nick\2                           Status                      \02Server\02", me.name, cptr->name);
    sendto_one(cptr, ":%s 009 %s :",
                me.name, cptr->name);

    for (acptr = client; acptr; acptr = acptr->next)
    {
        if (IsPerson(acptr) && IsAnOper(acptr) && !IsULine(acptr) && !IsHideOper(acptr))
        {
            buf[0] = '\0';
            sendto_one(cptr, ":%s 009 %s :%-30s  %-9s %-9s  %s",me.name, cptr->name,
                    acptr->name ? acptr->name : "<Desconhecido>",
		    IsIRCAdmin(acptr) ? "IRC Administrator" : IsNetAdmin(acptr) ? "Network Administrator" : IsCoAdmin(acptr) ? "Co-Administrator" : IsTechAdmin(acptr) ? "Technical Administrator" : IsSAdmin(acptr) ? "Services Administrator" : IsAdmin(acptr) ? "Server Administrator" : IsServerCoAdmin(acptr) ? "Server Co-Administrator" : IsOper(acptr) ? "Global Operator" : "Local Operator",
		    acptr->user->away ? "(Away)" : "",
		    acptr->user->server);

	    totalops++;
	}
    }

    if (totalops == 0)
        sendto_one(cptr, ":%s 009 %s :No On-Line Opers ",me.name, cptr->name);
    sendto_one(cptr, ":%s 009 %s :",
        me.name, cptr->name);
    sendto_one(cptr, ":%s 009 %s :Total:  %d  Operator(s) connected.", me.name, cptr->name, totalops);
    sendto_one(cptr, ":%s 009 %s :",
        me.name, cptr->name);
}

/*
** m_relay
**      parv[0] = sender
**      parv[1] = server pattern to relay to
**      parv[2] = string to relay
*/

CMD_FUNC(m_relay)
{
        Link *lp;

        if (!(IsNetAdmin(sptr) || IsCoAdmin(sptr) || IsServer(cptr) || IsULine(sptr))) {
                sendto_one(sptr, err_str(ERR_NOPRIVILEGES), me.name, parv[0]);
                return -1;
        }

        if (parc < 3 || *parv[1] == '\0')
        {
                sendto_one(sptr, err_str(ERR_NEEDMOREPARAMS), me.name, parv[0], "RELAY");
                return -1;
        }

        if (!IsServer(cptr)) {
                sendto_serv_butone(&me,
                    ":%s GLOBOPS :%s is RELAYing [%s] to %s",
                    me.name, sptr->name, parv[2], parv[1]);
                sendto_realops
                    ("%s is RELAYing [%s] to %s",
                    parv[0], parv[2], parv[1]);
        }

        if (hunt_server(cptr, sptr, ":%s RELAY %s :%s", 1, parc, parv) == HUNTED_ISME) {
                parse(sptr, parv[2], (parv[2] + strlen(parv[2])));
        }

        return 0;
}

/*
** m_grelay
**      parv[0] = sender
**      parv[1] = string to relay
*/

CMD_FUNC(m_grelay)
{
        Link *lp;

        if (!(IsNetAdmin(sptr) || IsCoAdmin(sptr) || IsULine(sptr))) {
                sendto_one(sptr, err_str(ERR_NOPRIVILEGES), me.name, parv[0]);
                return -1;
        }

        if (parc < 2 || *parv[1] == '\0')
        {
                sendto_one(sptr, err_str(ERR_NEEDMOREPARAMS), me.name, parv[0], "GRELAY");
                return -1;
        }

        sendto_serv_butone(&me,
            ":%s GLOBOPS :%s is GRELAYing [%s]",
            me.name, sptr->name, parv[1]);
        sendto_realops
            ("%s is GRELAYing [%s]",
            parv[0], parv[1]);


        parv[2] = parv[1];
        parc++;

        for (lp = Servers; lp; lp = lp->next) {
                parv[1] = lp->value.cptr->name;
                if (hunt_server(cptr, sptr, ":%s RELAY %s :%s", 1, parc, parv) == HUNTED_ISME) {
                        parse(sptr, parv[2], (parv[2] + strlen(parv[2])));
                        break;
                }
        }

        return 0;
}

/*
** m_glag
**      parv[0] = sender
*/

CMD_FUNC(m_glag)
{
        Link *lp;

        if (!IsOper(sptr)) {
                sendto_one(sptr, err_str(ERR_NOPRIVILEGES), me.name, parv[0]);
                return -1;
        }

        for (lp = Servers; lp; lp = lp->next) {
                parv[1] = lp->value.cptr->name;
                if (hunt_server(cptr, sptr, ":%s RELAY %s :LAG", 1, 2, parv) == HUNTED_ISME) {
                        parv[2] = strdup("LAG");
                        parse(sptr, parv[2], (parv[2] + 3));
                        free(parv[2]);
                        break;
                }
        }

        return 0;
}
